/*
-------------------------------------------------------------------------------
Name:	TB_PasteAboveorUnderLayer

Description: This script contains functions that allow the user to copy a layer 
  and paste it across multiple panels at a specific point under or over the 
  layer they choose. If the same panel the original layer was copied from is 
  pasted across, a duplicate layer will be added to that panel.

Usage:	Copy Layer(s), then run script.

Author:	Corey Barnes and Karl Olson

Created: 2020/4/02

Version: 1.0.0

Feedback/Bugs contact: livingfruitvirus@gmail.com

Twitter:
Corey - http://twitter.com/myanimewaifu
Karl - http://twitter.com/karlrolson
-------------------------------------------------------------------------------
*/

function PasteAboveLayer() {
  PasteLayer(false);
}

function PasteUnderLayer() {
  PasteLayer(true);
}

function PasteLayer(under) {
  // Paste layer and change alignment

  var selMgr = new SelectionManager();
  var layMgr = new LayerManager();

  var panelSel = selMgr.getPanelSelection();
  if (panelSel.length <= 0) return;

  // Change the dialog's wording depending on the action we're taking
  var layerAction = under ? "Under" : "Over";

  // Create a list of all layer names in the selected panels
  var layerNames = new Array(0);
  for (var i = 0; i < panelSel.length; i++) {
    var panelId = panelSel[i];
    var numberOfLayers = layMgr.numberOfLayers(panelId);

    for (var j = 0; j < numberOfLayers; ++j) {
      var layerName = layMgr.layerName(panelId, j);

      if (layerNames.indexOf(layerName) == -1) layerNames.push(layerName);
    }
  }

  // Create a radio button box of all the layers they wish to spread out.
  var d = new Dialog();
  d.title = "Paste " + layerAction + " Layer";

  var group = new GroupBox();
  group.title = "Choose The Layer to Paste " + layerAction + ".";
  var count = 0;
  var radioButtonsArray = new Array(0);

  for (var ie = 0; ie < layerNames.length; ++ie) {
    var c = new RadioButton();
    c.text = layerNames[ie];
    count++;
    radioButtonsArray.push(c);
    group.add(c);
  }

  d.add(group);

  var rca = d.exec();

  // If dialog cancelled, return
  if (!rca) {
    return;
  }

  // Retrieve the selected layer name
  var selectedLayer;
  for (var i = 0; i < count; ++i) {
    var r = radioButtonsArray[i];
    if (r.checked == true) {
      selectedLayer = radioButtonsArray[i].text;
      break;
    }
  }

  // Run script
  scene.beginUndoRedoAccum("Paste" + layerAction + "Layer");

  // Begin the indexing of panels
  for (var i = 0; i < panelSel.length; i++) {
    var thisPanel = panelSel[i];
    var underLayer = new Array(0); // Array to hold the layer object

    // Move the playhead to the next panel in the index
    selMgr.setCurrentPanel(thisPanel);

    // Get the number of layers
    numLayers = layMgr.numberOfLayers(thisPanel);

    // Begin the indexing of layers
    for (var j = 0; j < numLayers; j++) {
      if (layMgr.layerName(thisPanel, j) == selectedLayer) {
        // If the layer being indexed is the layer picked by the user
        underLayer[0] = {
          name: selectedLayer,
          panelId: thisPanel
        };

        // Select the layer as defined by the user
        selMgr.setLayerSelection(underLayer);

        // if under, select the layer beneath the layer the user's selection
        if (under) {
          Action.perform("onActionSelectPreviousLayer()");
        }

        // Paste the layer
        Action.perform("onActionPasteLayers()");
        break;
      }
    }
  }

  scene.endUndoRedoAccum();
}
